<?php

//////////
///
///   limits.inc.php
///
//////////

require_once('lib/db.inc.php');
require_once('lib/err.inc.php');



$limits = unserialize(rcs_getlimits());



/***************\
*   FUNCTIONS   *
\***************/

function getlimit($limit)
{
   global $limits;

   $limits[$limit] = (isset($limits[$limit]) ? $limits[$limit] : 0);

   if($limits[$limit] == -1) {
      return success(-1);
   }

   switch($limit) {
      case 'user':
         $sql  = "SELECT COUNT(`user_id`) AS `count` ";
         $sql .= "FROM `user`";

         break;
      case 'backdoor':
         $sql  = "SELECT COUNT(`backdoor_id`) AS `count` ";
         $sql .= "FROM `backdoor` ";
         $sql .= "JOIN `target` ";
         $sql .= "USING (`target_id`) ";
         $sql .= "JOIN `activity` ";
         $sql .= "USING (`activity_id`) ";
         $sql .= "WHERE `backdoor`.`deleted` = '0' AND ";
         $sql .=       "`activity`.`status` = 'OPEN'";

         break;
      case 'backdoor_WIN32':
         $sql  = "SELECT COUNT(`backdoor_id`) AS `count` ";
         $sql .= "FROM `backdoor` ";
         $sql .= "JOIN `target` ";
         $sql .= "USING (`target_id`) ";
         $sql .= "JOIN `activity` ";
         $sql .= "USING (`activity_id`) ";
         $sql .= "WHERE `backdoor`.`deleted` = '0' AND ";
         $sql .=       "`activity`.`status` = 'OPEN' AND ";
         $sql .=       "`backdoor`.`type` = 'WIN32'";

         break;
      case 'backdoor_WINMOBILE':
         $sql  = "SELECT COUNT(`backdoor_id`) AS `count` ";
         $sql .= "FROM `backdoor` ";
         $sql .= "JOIN `target` ";
         $sql .= "USING (`target_id`) ";
         $sql .= "JOIN `activity` ";
         $sql .= "USING (`activity_id`) ";
         $sql .= "WHERE `backdoor`.`deleted` = '0' AND ";
         $sql .=       "`activity`.`status` = 'OPEN' AND ";
         $sql .=       "`backdoor`.`type` = 'WINMOBILE'";

         break;
      default:
         return success(true);
   }

   $ret = db_query($sql);

   if(!is_success($ret)) {
      return $ret;
   }

   if($ret['payload'][0]->count == $limits[$limit]) {
      return success(false);
   } else if($ret['payload'][0]->count > $limits[$limit]) {
      return error('limit', 'invalidlicense');
   }

   return success((integer)($limits[$limit] - $ret['payload'][0]->count));
}

function checklimits()
{
   global $limits;

   foreach(array('serial', 'user', 'backdoor', 'begin', 'end') as $limit) {
      if(!isset($limits[$limit])) {
         return error('limit', 'invalidlicense');
      }
   }

   if(($limits['serial'] != "off") && ((($serial = rcs_getserial()) === false) || ($serial != $limits['serial']))) {
      return error('limit', 'invalidlicense');
   }

   $now = time();

   if((($limits['begin'] != -1) && ($now < $limits['begin'])) || (($limits['end'] != -1) && ($now > $limits['end']))) {
      return error('limit', 'invalidlicense');
   }

   foreach(array('user', 'backdoor', 'backdoor_WIN32', 'backdoor_WINMOBILE') as $limit) {
      $ret = getlimit($limit);

      if(!is_success($ret)) {
         return $ret;
      }
   }

   return success(true);
}

?>
